@@ -21,6 +21,7 @@
 #include "qalculate_tde_utils.h"
 #include "qalculateeditnamesdialog.h"
 
+#include <string>
 #include <tqgrid.h>
 #include <klineedit.h>
 #include <kpushbutton.h>
@@ -204,7 +205,7 @@ void QalculateEditDataSetDialog::updateDatasetPropertyList() {
 
 void QalculateEditDataSetDialog::slotOk() {
 
-	string str = nameEdit->text().ascii();
+	std::string str = nameEdit->text().ascii();
 	remove_blank_ends(str);
 	if(str.empty() && (!names_edit_dialog || names_edit_dialog->isEmpty())) {
 		//no name -- open dialog again
@@ -491,7 +492,7 @@ QalculateEditDataPropertyDialog::~QalculateEditDataPropertyDialog() {}
 
 void QalculateEditDataPropertyDialog::slotOk() {
 
-	string str = nameEdit->text().ascii();
+	std::string str = nameEdit->text().ascii();
 	remove_blank_ends(str);
 	if(str.empty() && (!names_edit_dialog || names_edit_dialog->isEmpty())) {
 		//no name -- open dialog again
