@@ -21,6 +21,7 @@
 #include "qalculate_tde_utils.h"
 #include "qalculateeditnamesdialog.h"
 
+#include <string>
 #include <tqgrid.h>
 #include <klineedit.h>
 #include <kpushbutton.h>
@@ -178,9 +179,9 @@ void QalculateEditFunctionDialog::argumentRenamed(TQListViewItem *i, const TQStr
 
 void QalculateEditFunctionDialog::slotOk() {
 
-	string str = nameEdit->text().ascii();
+	std::string str = nameEdit->text().ascii();
 	remove_blank_ends(str);
-	string str2 = CALCULATOR->unlocalizeExpression(expressionEdit->text().ascii(), evalops.parse_options);
+	std::string str2 = CALCULATOR->unlocalizeExpression(expressionEdit->text().ascii(), evalops.parse_options);
 	remove_blank_ends(str2);
 	gsub("\n", " ", str2);
 	if(str.empty() && (!names_edit_dialog || names_edit_dialog->isEmpty())) {
