@@ -146,7 +146,7 @@ TQString linkInfo(const MathStructure *m, TQWidget *w, bool full_length = false)
 					str += "<br>";
 					str += "<br>";
 					TQString str2;
-					str2.sprintf(i18n("Retrieves data from the %s data set for a given object and property. If \"info\" is typed as property, a dialog window will pop up with all properties of the object."), f->title().c_str());
+					str2.sprintf(i18n("Retrieves data from the %s data set for a given object and property. If \"info\" is typed as property, a dialog window will pop up with all properties of the object.").utf8(), f->title().c_str());
 					str2.replace("<", "&lt;");
 					str2.replace(">", "&gt;");
 					str += str2;
